@@ -63,13 +63,16 @@ from ..base import BaseParser
 
 class Parser(BaseParser):
 
-    def line_to_dict(self, line):
+    def line_to_dict(self, line, cfg=None):
         """
         Parses a PBS log file line into a python dict
 
         raises ValueError when line not valid
 
         """
+        if cfg is None:
+            cfg = {}
+
         logger.debug('Parsing line:')
         logger.debug(line)
         # Split line into parts, only care about raw_data
@@ -95,18 +98,27 @@ class Parser(BaseParser):
             return None
 
         formatted_data['user'] = data['user']
+        formatted_data['project'] = None
         if 'project' in data:
             formatted_data['project'] = data['project']
         elif 'account' in data:
             formatted_data['project'] = data['account']
 
+        ignore_project = cfg.get('ignore_project', None)
+        if ignore_project is not None \
+                and formatted_data['project'] == ignore_project:
+            formatted_data['project'] = None
+
+        if formatted_data['project'] is None:
+            formatted_data['project'] = cfg.get('default_project', None)
+
         formatted_data['jobname'] = data['jobname']
         formatted_data['group'] = data['group']
 
         formatted_data['act_wall_time'] = \
             get_in_seconds(data['resources_used.walltime'])
 
-        if 'est_wall_time' in data:
+        if 'Resource_List.walltime' in data:
             formatted_data['est_wall_time'] = \
                 get_in_seconds(data.get('Resource_List.walltime'))
         else:
@@ -114,7 +126,11 @@ class Parser(BaseParser):
 
         formatted_data['exec_hosts'] = \
             [x[:-2] for x in data['exec_host'].split('+')]
-        cores = data['exec_host'].count('/')
+
+        if 'resources_used.ncpus' in data:
+            cores = int(data['resources_used.ncpus'])
+        else:
+            cores = data['exec_host'].count('/')
         formatted_data['cores'] = cores
         formatted_data['cpu_usage'] = cores * formatted_data['act_wall_time']
 
