@@ -36,6 +36,9 @@ _force_rebuild = False
 
 
 class Base(object):
+    def __init__(self, *args, **kwargs):
+        super(Base, self).__init__(*args, **kwargs)
+        self.maxDiff = None
 
     def test_line_to_dict(self):
         directory = os.path.abspath(os.path.split(examples.__file__)[0])
@@ -92,7 +95,7 @@ class Base(object):
                 test_results.append(result1)
 
             with open(path, "w") as fp:
-                json.dump(test_results, fp, indent=4)
+                json.dump(test_results, fp, sort_keys=True, indent=4)
 
     def get_cfg(self):
         directory = os.path.abspath(os.path.split(examples.__file__)[0])
@@ -141,6 +144,6 @@ class Base(object):
                 test_results.append(result)
 
             with open(path, "w") as fp:
-                json.dump(test_results, fp, indent=4)
+                json.dump(test_results, fp, sort_keys=True, indent=4)
 
             shutil.copyfile(text_path, expected_text_path)
